==> haskell-setenv-0.1.1.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: setenv
version: 0.1.1.3
id: setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl
key: setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl
license: MIT
copyright: (c) 2012-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables
    .
    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.
category: System
abi: f590a47c94186759709b79b52a1e0710
exposed: True
exposed-modules:
    System.SetEnv
import-dirs: /usr/lib/ghc-8.4.3/site-local/setenv-0.1.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/setenv-0.1.1.3
hs-libraries: HSsetenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl
depends:
    base-4.11.1.0 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html: /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-setenv-0.1.1.3-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: setenv
version: 0.1.1.3
id: setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
key: setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
license: MIT
copyright: (c) 2012-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables
    .
    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.
category: System
abi: 5c2d7d38e8e2d30120888c331f00bc51
exposed: True
exposed-modules:
    System.SetEnv
import-dirs: /usr/lib/ghc-8.6.1/site-local/setenv-0.1.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/setenv-0.1.1.3
hs-libraries: HSsetenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
depends:
    base-4.12.0.0 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html: /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
